From 370308fb8381b55e7ebfcdd77f1361b49a288f88 Mon Sep 17 00:00:00 2001
From: Andreas Sturmlechner <andreas.sturmlechner@gmail.com>
Date: Sun, 17 Feb 2019 23:51:03 +0100
Subject: [PATCH] Un-break optional Qt5/KF5 detection

---
 core/CMakeLists.txt | 58 ++++++++++++++++-----------------------------
 1 file changed, 20 insertions(+), 38 deletions(-)

diff --git a/core/CMakeLists.txt b/core/CMakeLists.txt
index 16bba83335..b8cdc59baa 100644
--- a/core/CMakeLists.txt
+++ b/core/CMakeLists.txt
@@ -65,17 +65,14 @@ find_package(Qt5 ${QT_MIN_VERSION} REQUIRED
 )
 
 if(ENABLE_QWEBENGINE)
-    find_package(Qt5 ${QT_MIN_VERSION} REQUIRED NO_MODULE COMPONENTS WebEngineWidgets)
+    find_package(Qt5WebEngineWidgets ${QT_MIN_VERSION} REQUIRED NO_MODULE)
 else()
-    find_package(Qt5 ${QT_MIN_VERSION} REQUIRED NO_MODULE COMPONENTS WebKitWidgets)
+    find_package(Qt5WebKitWidgets ${QT_MIN_VERSION} REQUIRED NO_MODULE)
 endif()
 
-find_package(Qt5 ${QT_MIN_VERSION}
-             OPTIONAL_COMPONENTS
-             DBus
-             OpenGL
-             XmlPatterns                # For Rajce plugin
-)
+find_package(Qt5DBus ${QT_MIN_VERSION})
+find_package(Qt5OpenGL ${QT_MIN_VERSION})
+find_package(Qt5XmlPatterns ${QT_MIN_VERSION}) # For Rajce plugin
 
 if(ENABLE_DBUS)
     if(NOT Qt5DBus_FOUND)
@@ -86,16 +83,11 @@ endif()
 # Dependencies For unit tests and CLI test tools
 
 if(BUILD_TESTING)
-    find_package(Qt5 ${QT_MIN_VERSION} REQUIRED
-                 NO_MODULE COMPONENTS
-                 Test
-    )
-
-    find_package(Qt5 ${QT_MIN_VERSION}
-                 QUIET
-                 OPTIONAL_COMPONENTS
-                 Qml WebView  # Optional, for 'sialis' O2 library test tool.
-    )
+    find_package(Qt5Test ${QT_MIN_VERSION} NO_MODULE)
+    
+    # Optional, for 'sialis' O2 library test tool.
+    find_package(Qt5Qml ${QT_MIN_VERSION} QUIET NO_MODULE)
+    find_package(Qt5WebView ${QT_MIN_VERSION} QUIET NO_MODULE)
 endif()
 
 find_package(KF5 ${KF5_MIN_VERSION} REQUIRED
@@ -113,38 +105,28 @@ find_package(KF5 ${KF5_MIN_VERSION} QUIET
              OPTIONAL_COMPONENTS
              KIO                    # For Desktop integration (Widgets only).
              IconThemes             # For Desktop integration.
-             FileMetaData           # For KDE file indexer support.
              ThreadWeaver           # For Panorama tool.
              NotifyConfig           # KDE desktop application notify configuration.
              Notifications          # KDE desktop notifications integration.
 )
 
-find_package(KF5 ${AKONADI_MIN_VERSION} QUIET
-             OPTIONAL_COMPONENTS
-             AkonadiContact         # For KDE Mail Contacts support.
-             Contacts               # API for contacts/address book data.
-)
+find_package(KF5Sane ${KSANE_MIN_VERSION} QUIET) # For digital scanner support.
 
-find_package(KF5 ${KSANE_MIN_VERSION} QUIET
-             OPTIONAL_COMPONENTS
-             Sane                   # For digital scanner support.
-)
-
-find_package(KF5 ${CALENDAR_MIN_VERSION} QUIET
-             OPTIONAL_COMPONENTS
-             CalendarCore           # For Calendar tool.
-)
+find_package(KF5CalendarCore ${CALENDAR_MIN_VERSION} QUIET) # For Calendar tool.
 
 if ("${KF5CalendarCore_VERSION}" VERSION_GREATER 5.6.40)
     set(HAVE_KCALENDAR_QDATETIME TRUE)
 endif()
 
-if(ENABLE_AKONADICONTACTSUPPORT AND (NOT KF5AkonadiContact_FOUND OR NOT KF5Contacts_FOUND))
-    set(ENABLE_AKONADICONTACTSUPPORT OFF)
+if(ENABLE_AKONADICONTACTSUPPORT)
+    find_package(KF5 ${AKONADI_MIN_VERSION} REQUIRED
+                AkonadiContact         # For KDE Mail Contacts support.
+                Contacts               # API for contacts/address book data.
+    )
 endif()
 
-if(ENABLE_KFILEMETADATASUPPORT AND NOT KF5FileMetaData_FOUND)
-    set(ENABLE_KFILEMETADATASUPPORT OFF)
+if(ENABLE_KFILEMETADATASUPPORT)
+    find_package(KF5FileMetaData ${KF5_MIN_VERSION} REQUIRED) # For KDE file indexer support.
 endif()
 
 # Check if KIO have been compiled with KIOWidgets. digiKam only needs this one.
@@ -275,7 +257,7 @@ endif()
 find_package(X11)
 
 if(X11_FOUND)
-    find_package(Qt5 ${QT_MIN_VERSION} NO_MODULE COMPONENTS X11Extras)
+    find_package(Qt5X11Extras ${QT_MIN_VERSION} NO_MODULE)
     set(HAVE_X11 TRUE)
 else()
     set(HAVE_X11 FALSE)
-- 
2.34.1

